@@ -1,9 +1,10 @@
 package Padre::Plugin::HTMLExport;
 
+use 5.006;
 use warnings;
 use strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use File::Basename ();
 
@@ -93,7 +94,7 @@ sub export_html {
 	}
 	
 	# highlight
-	my $mimetype = $doc->mimetype;
+	my $mimetype = $doc->get_mimetype;
 	unless ( exists $KATE_ALL{$mimetype} ) {
 		$self->error("$mimetype is not supported");
 		return;
